@@ -245,9 +245,10 @@ static gboolean load_icons_from_disk (gpointer data){
 
 	//Load compositions
 	gchar *filepath1;
-	filepath1 = COMPOSITIONS_DIRECTORY;
+	filepath1 = configure_get_compositions_directory();
 	
 	GList* files = file_helper_get_all_files(filepath1);
+	g_free(filepath1);
 
 	int counter1=0;
 	GList* l;
@@ -282,7 +283,9 @@ static gboolean load_icons_from_disk (gpointer data){
 
 
 	//And singings
-	files = file_helper_get_all_files(SINGINGS_DIRECTORY); //There are also folder named 'wavs', but it is not harmfull
+	gchar* singings_directory=configure_get_singings_directory();
+	files = file_helper_get_all_files(singings_directory); //There are also folder named 'wavs', but it is not harmfull
+	g_free(singings_directory);
 
 	int counter2=0;
 	for (l = files; l; l = l->next)
