@@ -24,6 +24,7 @@
 #include "../jammo-cursor.h"
 #include "../jammo.h"
 
+#include "../../cem/cem.h"
 #include "gui.h"
 #include "chum.h" /*For SCREEN_*-macros */
 #include "file_helper.h"
@@ -132,16 +133,16 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 
 	printf("do saving\n");
 
-	time_t rawtime;
-	struct tm * timeinfo;
 	char timestamp_now [80];
-	time ( &rawtime );
-	timeinfo = localtime ( &rawtime );
-	strftime (timestamp_now,80,"%Y.%m.%d_%H.%M.%S",timeinfo);
+	cem_get_time(timestamp_now);
 
-	char* filename= g_strdup_printf("%s/wavs/%s_%s.wav",SINGINGS_DIRECTORY,(chum_get_current_song())->name_with_pack,timestamp_now);
+	gchar* singings_directory = configure_get_singings_directory();
+	char* filename= g_strdup_printf("%s/wavs/%s_%s.wav",singings_directory,(chum_get_current_song())->name_with_pack,timestamp_now);
+
+	gchar* jammo_directory=configure_get_jammo_directory();
+	cmd = g_strdup_printf("mv \"%s/last_recorded.wav\" \"%s\"", jammo_directory, filename);
+	g_free(jammo_directory);
 
-	cmd = g_strdup_printf("mv \"%s/last_recorded.wav\" \"%s\"", JAMMO_DIRECTORY, filename);
 	//printf("Executing: '%s'\n",cmd);
 	if (system(cmd)) 
 		printf("Error, can't call '%s'\n",cmd);
@@ -149,7 +150,8 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 
 	FILE *ofp;
 	gchar *outputFilename;
-	outputFilename = g_strdup_printf("%s/%s.json", SINGINGS_DIRECTORY,(chum_get_current_song())->name_with_pack);
+	outputFilename = g_strdup_printf("%s/%s.json", singings_directory,(chum_get_current_song())->name_with_pack);
+	g_free(singings_directory);
 
 	//printf("outputFilename='%s'\n",outputFilename);
 	ofp = fopen(outputFilename, "w");
@@ -207,7 +209,9 @@ void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user
 
 
 	gchar *loaded_filename;
-	loaded_filename =  g_strdup_printf("%s/last_recorded.wav",JAMMO_DIRECTORY);
+	gchar* jammo_directory=configure_get_jammo_directory();
+	loaded_filename =  g_strdup_printf("%s/last_recorded.wav",jammo_directory);
+	g_free(jammo_directory);
 	printf("looking for file '%s' for loaded_track\n",loaded_filename);	
 
 
