@@ -355,7 +355,9 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track));
 		g_free(filename);
 
-		gchar* recording_filename = g_strdup_printf("%s/last_recorded.wav",JAMMO_DIRECTORY);
+		gchar* jammo_directory=configure_get_jammo_directory();
+		gchar* recording_filename = g_strdup_printf("%s/last_recorded.wav",jammo_directory);
+		g_free(jammo_directory);
 		JammoRecordingTrack* recording_track;
 
 
@@ -476,7 +478,7 @@ static void icon_offset_from_json(char* filename, gfloat* x,gfloat* y, gfloat* w
   if (!json_parser_load_from_file (parser, filename, NULL))
         {
           gchar* message = g_strdup_printf("Can't load file '%s' for json-parsing. Using default values",filename);
-          cem_add_to_log(message,LOG_WARN);
+          cem_add_to_log(message,J_LOG_WARN);
           g_free(message);
           g_object_unref (parser);
           return;
