@@ -135,7 +135,7 @@ static void end_backingtrack_selection() {
 	}
 
 	clutter_actor_hide(jammo_get_actor_by_id("backingtrack-selection-view"));
-	clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));
+	return_to_fullsequencer_gui();
 }
 
 
