@@ -8,6 +8,7 @@ This is the sequencer.
 #include <glib-object.h>
 #include "gamesmenu.h"
 #include "startmenu.h"
+#include "sequencer.h"
 #include "../jammo.h"
 
 #include "../jammo-game-task.h"
@@ -38,16 +39,44 @@ gboolean start_gamesmenu()
 	return FALSE;
 }
 
-void start_level_composing(TangleButton* button,gpointer data) {
+void gamesmenu_start_first_task_on_this_level(const char* levelname) {
+printf("Starting level: '%s'\n",levelname);
+
 	clutter_actor_hide(jammo_get_actor_by_id("gamesmenu-view"));
 	//tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("gamesmenu-view")));
 
-	tangle_view_load_now(TANGLE_VIEW(jammo_get_actor_by_id("level1-view"))); //Needed for task-name
-	jammo_game_level_start_task(JAMMO_GAME_LEVEL(jammo_get_object_by_id("game-level")),"level1-task1.json");
-	clutter_actor_show(jammo_get_actor_by_id("level1-view"));
-	start_sequencer_full_sequencer(NULL,NULL,NULL,NULL); //FIXME: this was previously called when fullscreen-view is showed
+	gchar* view_name = g_strdup_printf("%s-view",levelname);
+	ClutterActor* levelview = jammo_get_actor_by_id(view_name);
+	g_free(view_name);
+	if (levelview==NULL)
+		printf("levelview '%s' was NULL\n",view_name);
+	else
+		printf("levelview not NULL\n");
+
+
+	tangle_view_load_now(TANGLE_VIEW(levelview)); //Needed for task-name
+	JammoGameLevel* game_level = JAMMO_GAME_LEVEL(jammo_get_object_by_id("game-level"));
+	if (game_level==NULL)
+		printf("game_level was NULL\n");
+	else
+		printf("game_level not NULL\n");
+
+	gchar* task_name = g_strdup_printf("%s-task1.json",levelname);
+	jammo_game_level_start_task(game_level,task_name);
+	g_free(task_name);
+	start_fullsequencer_gui(levelview);
 }
 
+
+void start_level_composing(TangleButton* button,gpointer data) {
+	gamesmenu_start_first_task_on_this_level("level1");
+}
+
+void start_level_instrument(TangleButton* button,gpointer data) {
+	gamesmenu_start_first_task_on_this_level("level3");
+}
+
+
 gboolean on_start_button_clicked(JammoGameLevel* game_level, TangleButton* button) {
 	const gchar* name;
 	name = clutter_actor_get_name(CLUTTER_ACTOR(button));
