@@ -122,7 +122,8 @@ void start_fullsequencer_gui(ClutterActor* levelview)
 }
 
 void return_to_fullsequencer_gui(){
-clutter_actor_show(current_levelview);
+	clutter_actor_show(CLUTTER_ACTOR(jammo_mentor_get_default()));
+	clutter_actor_show(current_levelview);
 }
 
 /*
