@@ -6,18 +6,11 @@ This file is for clutter based gui.
 #ifndef _SEQUENCER_H_
 #define _SEQUENCER_H_
 
-
-gchar* inputFilename;
-void start_sequencer(gpointer filename);
-void init_sequencer();
-gboolean sequencer_is_initialized();
-void sequencer_change_view_to_sequencer();
-void leave_sequencer();
+void start_fullsequencer_gui(ClutterActor* levelview);
 
 gboolean sequencer_change_to_loop_view(TangleActor *actor, gpointer data);
 gboolean sequencer_change_to_sequencer_view(TangleActor *actor, gpointer data);
 gboolean sequencer_change_to_bottom_view(TangleActor *actor, gpointer data);
-
-
+void return_to_fullsequencer_gui();
 #endif /* _SEQUENCER_H_ */
 
