@@ -51,7 +51,7 @@ gboolean sequencer_lock_pressed (TangleButton* tanglebutton, gpointer data){
 
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
 	gchar* message = g_strdup_printf("Wheel_game: Lock '%s' pressed",name);
-	cem_add_to_log(message,LOG_USER_ACTION);
+	cem_add_to_log(message,J_LOG_USER_ACTION);
 	g_free(message);
 
 	ClutterActor* scroller = NULL;
@@ -65,7 +65,7 @@ gboolean sequencer_lock_pressed (TangleButton* tanglebutton, gpointer data){
 		scroller = effect_sample_looper;
 
 	else {
-		cem_add_to_log("can't detect which lock pressed",LOG_WARN);
+		cem_add_to_log("can't detect which lock pressed",J_LOG_WARN);
 		return FALSE;
 	}
 
@@ -114,7 +114,11 @@ static JammoSample* get_centermost_sample_from_loop_roll(ClutterActor* wheel) {
 	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(scroll_action), &not_used,&offset);
 
 	//Check height of first sample-button, suppose all have same height
-	offset+= clutter_actor_get_height(tangle_widget_get_nth_child(TANGLE_WIDGET(wheel),0));
+	ClutterActor* first_actor = tangle_widget_get_nth_child(TANGLE_WIDGET(wheel),0);
+	//If first is NULL, suppose they are all NULL.
+	if (first_actor==NULL)
+		return NULL;
+	offset+= clutter_actor_get_height(first_actor);
 
 	//Check height of the wheel
 	height = clutter_actor_get_height(wheel);
@@ -160,7 +164,7 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer data) {
  * plays all samples from centerline of loop rolls
  */
 void fullsequencer_loop_arrow_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	cem_add_to_log("fullsequencer_play_all_loops-clicked",LOG_USER_ACTION);
+	cem_add_to_log("fullsequencer_play_all_loops-clicked",J_LOG_USER_ACTION);
 
 	//get_centermost_sample_from_loop_roll can return NULL (in error cases)
 	JammoSample* r = get_centermost_sample_from_loop_roll(rhytmical_sample_looper);
@@ -244,7 +248,7 @@ static void rotate_to_place(ClutterActor* wheel, gint target_slot) {
 cannot_fail_lists is index for corresponding lists.
 */
 void fullsequencer_loop_cannot_fail_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	cem_add_to_log("fullsequencer_loop_cannot_fail_clicked-clicked",LOG_USER_ACTION);
+	cem_add_to_log("fullsequencer_loop_cannot_fail_clicked-clicked",J_LOG_USER_ACTION);
 
 	GRand *random_gen = g_rand_new();
 
@@ -261,7 +265,7 @@ void fullsequencer_loop_cannot_fail_clicked (TangleAction *action, GObject *sour
 
 //There will be some logic
 void fullsequencer_loop_crazy_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	cem_add_to_log("fullsequencer_loop_crazy_clicked-clicked",LOG_USER_ACTION);
+	cem_add_to_log("fullsequencer_loop_crazy_clicked-clicked",J_LOG_USER_ACTION);
 	GRand *random_gen = g_rand_new();
 
 	gint rot_rhyt = g_rand_int_range(random_gen, -30, 30);
@@ -286,14 +290,14 @@ DEPRECATED
 Bottom of the loop-view there are dropping-area, and when samplebutton is dragged here, view is changed.
 */
 gboolean sequencer_drag_begin(TangleDropAction* drop_action, TangleDragAction* drag_action){
-	cem_add_to_log("jammo_sample_button dragged from wheel to bottom of the screen",LOG_USER_ACTION);
+	cem_add_to_log("jammo_sample_button dragged from wheel to bottom of the screen",J_LOG_USER_ACTION);
 	sequencer_change_to_sequencer_view(NULL,NULL);
 	
 	return FALSE;
 }
 
 static void sample_button_drag_begin(JammoSampleButton* sample_button, gpointer data) {
-	cem_add_to_log("jammo_sample_button from wheel drag-begin",LOG_USER_ACTION);
+	cem_add_to_log("jammo_sample_button from wheel drag-begin",J_LOG_USER_ACTION);
 	sequencer_change_to_sequencer_view(NULL,NULL);
 }
 
@@ -740,6 +744,32 @@ static samplebutton_tuple effects[] = {
 
 
 #include "level1.h"
+//These tables are subsets of whole samplebuttons and used on level1-orientation game.
+static samplebutton_tuple level1_rhythms[] = {
+	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_8beat01_$t_44_1.ogg"},
+	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_16beat01_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_conga04_$t_44_1.ogg"},
+	{"wheel_game/shaker.png","wheel_game/Rh_shaker02_$t_44_1.ogg"},
+	{"wheel_game/tambourine.png","wheel_game/Rh_tambourine02_$t_44_1.ogg"},
+	{"wheel_game/acoustic_drumkit.png","wheel_game/Rh_tombeat01_$t_44_1.ogg"},
+	{"wheel_game/cahon.png","wheel_game/Rh_cajon08_$t_44_1.ogg"},
+	{"wheel_game/darabouka.png","wheel_game/Rh_djembe01_$t_44_1.ogg"},
+	{NULL,NULL}
+};
+
+static samplebutton_tuple level1_melodics[] = {
+	{"wheel_game/electric_piano.png", "wheel_game/Me_rhodes01_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthbell01_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthguitar01_$t_$p_44_1.ogg"},
+	{"wheel_game/synthesizer.png", "wheel_game/Me_synthriff_$t_$p_44_2.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax02_$t_$p_44_1.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Me_organ05_$t_$p_44_2.ogg"},
+	{"wheel_game/violin.png","wheel_game/Me_violin09_$t_$p_44_2.ogg"},
+	{"wheel_game/oboe.png", "wheel_game/Me_oboe04_$t_$p_44_1.ogg"},
+	{NULL,NULL}
+};
+
+
 /*
 loop_type:
 1000=rhythms
@@ -803,10 +833,16 @@ void sequencer_loop_tune_wheels(JammoGameTask* task) {
 	harmonical_sample_looper = tangle_widget_get_nth_child(TANGLE_WIDGET(container),2);
 	effect_sample_looper     = tangle_widget_get_nth_child(TANGLE_WIDGET(container),3);
 
-	length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,rhythms,1000,task);
-	length_of_melodics = add_sample_buttons(melodical_sample_looper,melodics,2000,task);
-	length_of_harmonics = add_sample_buttons(harmonical_sample_looper,harmonics,3000,task);
-	length_of_effects = add_sample_buttons(effect_sample_looper,effects,4000,task);
+	if (task) { //We suppose that task!=NULL means level1-task1 (TODO: make proper check)
+		length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,level1_rhythms,1000,task);
+		length_of_melodics = add_sample_buttons(melodical_sample_looper,level1_melodics,2000,task);
+	}
+	else {
+		length_of_rhythms = add_sample_buttons(rhytmical_sample_looper,rhythms,1000,task);
+		length_of_melodics = add_sample_buttons(melodical_sample_looper,melodics,2000,task);
+		length_of_harmonics = add_sample_buttons(harmonical_sample_looper,harmonics,3000,task);
+		length_of_effects = add_sample_buttons(effect_sample_looper,effects,4000,task);
+	}
 
 	fine_tune_wheel(rhytmical_sample_looper);
 	fine_tune_wheel(melodical_sample_looper);
