@@ -9,9 +9,7 @@
 //USE JAMMOS CONFIGURATION.H
 //#define PATH_DEVICE TRUE
 
-#define PG_PASSWORD_TEXT_FILE JAMMO_DIRECTORY "/pg-passwords"
 #define PG_IMAGES_DIR DATA_DIR "/password";
-#define INKML_FILE_PATH JAMMO_DIRECTORY "/motion_inkml.xml";
 #define PG_VERSION "v.0.7.1";
 
 //FULL SCREEN  MESSAGES 300x200 QUE FONTita! 32px
