@@ -8,7 +8,9 @@ FILE *ink_F;
 
 void create_ink_head()
 {
-  gchar *filepath = INKML_FILE_PATH;
+  gchar* jammo_directory=configure_get_jammo_directory();
+  gchar *filepath = g_build_filename(jammo_directory, "/motion_inkml.xml", NULL);
+  g_free(jammo_directory);
   ink_F = fopen(filepath, "w");
   if(ink_F ==NULL) {
     g_print("Cannot open file INKML..\n");
