@@ -74,7 +74,7 @@ gchar *pg_convert_points_to_string(int *array, int array_len)
 gboolean pg_save_passwd (gchar *passwd)
 {
 	FILE *passwd_F;
-	gchar *filepath = PG_PASSWORD_TEXT_FILE;
+	gchar *filepath = g_build_filename(configure_get_jammo_directory(), "/pg-passwords", NULL);
 	passwd_F = fopen(filepath, "w");
   	if(passwd_F ==NULL) {
     		g_print("Cannot open passwords file..\n");
@@ -88,7 +88,7 @@ gboolean pg_save_passwd (gchar *passwd)
 gchar *pg_read_passwd_from_file()
 {
 	FILE *passwd_F;
-	gchar *filepath = PG_PASSWORD_TEXT_FILE;
+	gchar *filepath = g_build_filename(configure_get_jammo_directory(), "/pg-passwords", NULL);
 	passwd_F=fopen(filepath,"rt");
 	if ( passwd_F != NULL ) 
 	{
