@@ -182,7 +182,7 @@ void jammo_gems_init(int argc, char* argv[])
 	else
 	{
 		logmsg = g_strdup_printf("NO PEERHOOD RUNNING - NETWORKING DISABLED");
-		cem_add_to_log(logmsg,LOG_DEBUG);
+		cem_add_to_log(logmsg,J_LOG_DEBUG);
 		g_free(logmsg);
 		
 		components->service_jammo->enabled = FALSE;
@@ -214,7 +214,7 @@ void jammo_gems_init(int argc, char* argv[])
 	chum_callback_game=empty_callback_game;
 
 	logmsg = g_strdup_printf("jammo_gems_init: done");
-	cem_add_to_log(logmsg,LOG_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_DEBUG);
 	g_free(logmsg);
 	//return components;
 }
@@ -230,7 +230,7 @@ void jammo_gems_cleanup()
 		components->service_group->group_info->own_state == IN_GROUP)	gems_group_leave_from_group();
 	
 	logmsg = g_strdup_printf("jammo_gems_cleanup: start");
-	cem_add_to_log(logmsg,LOG_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_DEBUG);
 	g_free(logmsg);
 	
 	if(components->pm != NULL) profilemanager_delete_manager(components->pm);
@@ -279,7 +279,7 @@ void jammo_gems_cleanup()
 	gems_free_data();
 	
 	logmsg = g_strdup_printf("jammo_gems_cleanup: done");
-	cem_add_to_log(logmsg,LOG_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_DEBUG);
 	g_free(logmsg);
 }
 
@@ -380,7 +380,7 @@ gems_peer_profile* gems_get_profile(gems_connection* element)
 void gems_ph_callback_notify(short aEvent, const char* aAddress,void* aData)
 {
 	gchar* logmsg = g_strdup_printf("gems_ph_callback_notify: event notify (%d) from %s.", aEvent,aAddress);
-	cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 }
 
@@ -416,13 +416,13 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 				if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 				{
 					logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_SERVICE_NOT_RUNNING (%s)",JAMMO_SERVICE_NAME);
-					cem_add_to_log(logerror,LOG_ERROR);
+					cem_add_to_log(logerror,J_LOG_ERROR);
 					g_free(logerror);
 				}
 				else
 				{
 					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_SERVICE_NOT_RUNNING (%s) to %s",JAMMO_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection));
-					cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
 			
@@ -442,13 +442,13 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 				if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 				{
 					logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_SERVICE_NOT_RUNNING (%s)", COLLABORATION_SERVICE_NAME);
-					cem_add_to_log(logerror,LOG_ERROR);
+					cem_add_to_log(logerror,J_LOG_ERROR);
 					g_free(logerror);
 				}
 				else
 				{
 					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_SERVICE_NOT_RUNNING (%s) to %s",COLLABORATION_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection));
-					cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
 			
@@ -468,13 +468,13 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 				if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 				{
 					logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_SERVICE_NOT_RUNNING (%s)", CONTROL_SERVICE_NAME);
-					cem_add_to_log(logerror,LOG_ERROR);
+					cem_add_to_log(logerror,J_LOG_ERROR);
 					g_free(logerror);
 				}
 				else
 				{
 					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_SERVICE_NOT_RUNNING (%s) to %s",CONTROL_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection));
-					cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 				}
 			
@@ -490,7 +490,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 					{
 						components->teacher_connection->connection = aConnection;
 						logmsg = g_strdup_printf("gems_ph_callback_newconnection: TEACHER CONNECTED from %s", ph_c_connection_get_remote_address(aConnection));
-						cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 					}
 					// Connection was established before
@@ -501,20 +501,20 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 						if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 						{
 							logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_CONNECTION_REJECTED (%s)", CONTROL_SERVICE_NAME);
-							cem_add_to_log(logerror,LOG_ERROR);
+							cem_add_to_log(logerror,J_LOG_ERROR);
 							g_free(logerror);
 						}
 						else
 						{
 							logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_CONNECTION_REJECTED (%s) to TEACHER %s",CONTROL_SERVICE_NAME, ph_c_connection_get_remote_address(aConnection));
-							cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 						}
 						
 						gems_clear_message(err);
 						
 						logmsg = g_strdup_printf("gems_ph_callback_newconnection: TEACHER CONNECTED from %s, TEACHER is already connected!", ph_c_connection_get_remote_address(aConnection));
-						cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
 						
 						ph_c_connection_delete(aConnection);
@@ -529,7 +529,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 		else
 		{
 			logmsg = g_strdup_printf("gems_ph_callback_newconnection: connecting to wrong port (connecting port %d)", aPort);
-			cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 			
 			err = gems_create_error_message(ERROR_CONNECTION_REJECTED_TYPE, 0);
@@ -537,13 +537,13 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 			if(gems_communication_write_data(ph_c_connection_get_fd(aConnection),err) != err->length)
 			{
 				logerror = g_strdup_printf("gems_ph_callback_newconnection: cannot write ERROR_CONNECTION_REJECTED");
-				cem_add_to_log(logerror,LOG_ERROR);
+				cem_add_to_log(logerror,J_LOG_ERROR);
 				g_free(logerror);
 			}
 			else
 			{
 				logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_CONNECTION_REJECTED to %s", ph_c_connection_get_remote_address(aConnection));
-				cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
 			}
 			
@@ -556,7 +556,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 		if((isconnected = gems_communication_already_connected(ph_c_connection_get_device_checksum(aConnection))) == NOT_IN_LIST)
 		{
 			logmsg = g_strdup_printf("gems_ph_callback_newconnection: Adding a connection with cid %d address %s..", aConnectionId, ph_c_connection_get_remote_address(aConnection));
-			cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 		
 			// Initialize connection object struct
@@ -566,7 +566,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 			components->initialized_connections = g_list_append(components->initialized_connections,(init_connection));
 		
 			logmsg = g_strdup_printf("gems_ph_callback_newconnection: new connection added to list");
-			cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 			
 			// Connection success, remove from errors. If no such device in the list, nothing is done
@@ -575,7 +575,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 		else if(isconnected == IN_REJECTED_LIST)
 		{
 			logmsg = g_strdup_printf("gems_ph_callback_newconnection: connection is in rejected list");
-			cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 			
 			message = gems_create_error_message(ERROR_CONNECTION_REJECTED_TYPE,JAMMO_SERVICE_ID);
@@ -584,17 +584,17 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 			{
 				case -1:
 					logerror = g_strdup_printf("gems_ph_callback_newconnection: Cannot write error ERROR_CONNECTION_REJECTED");
-					cem_add_to_log(logerror,LOG_ERROR);
+					cem_add_to_log(logerror,J_LOG_ERROR);
 					g_free(logerror);
 					break;
 				case 0:
 					logerror = g_strdup_printf("gems_ph_callback_newconnection: Wrote nothing");
-					cem_add_to_log(logerror,LOG_ERROR);
+					cem_add_to_log(logerror,J_LOG_ERROR);
 					g_free(logerror);
 					break;
 				default:
 					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_CONNECTION_REJECTED message data to %s", ph_c_connection_get_remote_address(aConnection));
-					cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					break;
 			}
@@ -625,7 +625,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 								{
 									element->game_connection = aConnection; // Add as game connection
 									logmsg = g_strdup_printf("gems_ph_callback_newconnection: Added Game connection for Collaboration");
-									cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+									cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 									g_free(logmsg);
 									return;
 								}
@@ -634,7 +634,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 								{
 									logerror = g_strdup_printf("gems_ph_callback_newconnection: Connection from %s/%d to %s who is not in the same group, disconnecting.", 
 									ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection), COLLABORATION_SERVICE_NAME);
-									cem_add_to_log(logerror,LOG_ERROR);
+									cem_add_to_log(logerror,J_LOG_ERROR);
 									g_free(logerror);
 									
 									err = gems_create_error_message(ERROR_NOT_IN_GROUP_TYPE,COLLABORATION_SERVICE_ID);
@@ -643,7 +643,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 									{
 										logerror = g_strdup_printf("gems_ph_callback_newconnection: error sending ERROR_NOT_IN_GROUP to %s/%d",
 											ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
-										cem_add_to_log(logerror,LOG_ERROR);
+										cem_add_to_log(logerror,J_LOG_ERROR);
 										g_free(logerror);
 									}
 									gems_clear_message(err);
@@ -657,7 +657,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 								// TODO error - no profile
 								logerror = g_strdup_printf("gems_ph_callback_newconnection: Connection from %s/%d to %s - no profile retrieved yet, disconnecting.", 
 								ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection), COLLABORATION_SERVICE_NAME);
-								cem_add_to_log(logerror,LOG_ERROR);
+								cem_add_to_log(logerror,J_LOG_ERROR);
 								g_free(logerror);
 							
 								ph_c_connection_delete(aConnection);
@@ -670,7 +670,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 						//error - group not active
 						logerror = g_strdup_printf("gems_ph_callback_newconnection: Connection from %s/%d to %s when group was not active.", 
 						ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection), COLLABORATION_SERVICE_NAME);
-						cem_add_to_log(logerror,LOG_ERROR);
+						cem_add_to_log(logerror,J_LOG_ERROR);
 						g_free(logerror);
 					
 						err = gems_create_error_message(ERROR_GROUP_NOT_ACTIVE_TYPE,COLLABORATION_SERVICE_ID);
@@ -679,7 +679,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 						{
 							logerror = g_strdup_printf("gems_ph_callback_newconnection: error sending ERROR_GROUP_NOT_ACTIVE to %s/%d",
 								ph_c_connection_get_remote_address(aConnection), ph_c_connection_get_device_checksum(aConnection));
-							cem_add_to_log(logerror,LOG_ERROR);
+							cem_add_to_log(logerror,J_LOG_ERROR);
 							g_free(logerror);
 						}
 
@@ -693,7 +693,7 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 			
 			// Otherwise already connected, send error
 			logmsg = g_strdup_printf("gems_ph_callback_newconnection: device is already connected");
-			cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
 			
 			message = gems_create_error_message(ERROR_ALREADY_CONNECTED_TYPE,JAMMO_SERVICE_ID);
@@ -702,17 +702,17 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 			{
 				case -1:
 					logerror = g_strdup_printf("gems_ph_callback_newconnection: Cannot write error ERROR_ALREADY_CONNECTED");
-					cem_add_to_log(logerror,LOG_ERROR);
+					cem_add_to_log(logerror,J_LOG_ERROR);
 					g_free(logerror);
 					break;
 				case 0:
 					logerror = g_strdup_printf("gems_ph_callback_newconnection: Wrote nothing");
-					cem_add_to_log(logerror,LOG_ERROR);
+					cem_add_to_log(logerror,J_LOG_ERROR);
 					g_free(logerror);
 					break;
 				default:
 					logmsg = g_strdup_printf("gems_ph_callback_newconnection: Wrote ERROR_ALREADY_CONNECTED message data to %s", ph_c_connection_get_remote_address(aConnection));
-					cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+					cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 					g_free(logmsg);
 					break;
 			}
@@ -794,7 +794,7 @@ gint gems_process_connections()
 					
 						if(logmsg != NULL)
 						{
-							cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
 							logmsg = NULL;
 						}
@@ -830,10 +830,10 @@ gint gems_process_connections()
 					cleanup_required = TRUE;
 			}
 		}
-		if(logmsg != NULL) cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+		if(logmsg != NULL) cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		logmsg = NULL;
-		if(logerror != NULL) cem_add_to_log(logerror,LOG_ERROR);
+		if(logerror != NULL) cem_add_to_log(logerror,J_LOG_ERROR);
 		g_free(logerror);
 		logerror = NULL;
 		
@@ -1012,7 +1012,7 @@ void gems_init_peerhood_callback()
 	gems_get_data()->ph_cb = ph_c_create_callback(notify, newconnection,(void*)gems_get_data(),(void*)gems_get_data());
 	
 	gchar* logmsg = g_strdup_printf("gems_networking_init_peerhood_callback: new callback created.");
-	cem_add_to_log(logmsg,LOG_INFO);
+	cem_add_to_log(logmsg,J_LOG_INFO);
 	g_free(logmsg);
 }
 
@@ -1052,7 +1052,7 @@ void gems_register_services()
 		components->service_jammo->enabled = FALSE;
 		logmsg = g_strdup_printf("gems_networking_register_services: cannot register %s service.",JAMMO_SERVICE_NAME);
 	}
-	cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 	
 	// Create JamMo service
@@ -1067,7 +1067,7 @@ void gems_register_services()
 		components->service_profile->enabled = FALSE;
 		logmsg = g_strdup_printf("gems_networking_register_services: cannot register %s service.",PROFILE_SERVICE_NAME);
 	}
-	cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 	
 	// Create JamMo service
@@ -1082,7 +1082,7 @@ void gems_register_services()
 		components->service_group->enabled = FALSE;
 		logmsg = g_strdup_printf("gems_networking_register_services: cannot register %s service.",GROUP_SERVICE_NAME);
 	}
-	cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 
 	// Create Collaboration service
@@ -1097,7 +1097,7 @@ void gems_register_services()
 		components->service_collaboration->enabled = FALSE;
 		logmsg = g_strdup_printf("gems_networking_register_services: cannot register %s service.",COLLABORATION_SERVICE_NAME);
 	}
-	cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 	
 	// Create Control service
@@ -1112,7 +1112,7 @@ void gems_register_services()
 		components->service_control->enabled = FALSE;
 		logmsg = g_strdup_printf("gems_networking_register_services: cannot register %s service.",CONTROL_SERVICE_NAME);
 	}
-	cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 
 }
