@@ -144,6 +144,19 @@ const gchar* jammo_sample_get_filename(JammoSample* sample) {
 	return sample->priv->filename;
 }
 
+/**
+ * jammo_sample_get_real_filename:
+ * @sample: a #JammoSample
+ *
+ * Returns the real file name of the audio data file.
+ *
+ * Return value: the real file name string
+ */
+const gchar* jammo_sample_get_real_filename(JammoSample* sample) {
+
+	return sample->priv->real_filename;
+}
+
 /**
  * jammo_sample_get_duration:
  * @sample: a #JammoSample
@@ -721,11 +734,18 @@ static void initialize_state(JammoSample* sample) {
 			}
 		} else {
 			sample->priv->element = gst_element_factory_make("gnlfilesource", NULL);
+			//printf("sample->priv->real_filename '%s'\n",sample->priv->real_filename);
 			g_object_set(sample->priv->element,
-	        		     "priority", 0,
-				     "location", sample->priv->real_filename,
-				     "media-start", 0 * GST_SECOND,
-					     NULL);
+                    "priority", 0,
+                    "media-start", 0 * GST_SECOND,
+                    NULL);
+			//If file is missing, then real_filename is NULL. Passing location NULL causes warning.
+			//Maybe we should do something more in this (error) case?
+			if (sample->priv->real_filename) {
+				g_object_set(sample->priv->element,
+                    "location", sample->priv->real_filename,
+                    NULL);
+			}
 			if (sample->priv->duration != JAMMO_DURATION_INVALID ||
 			    (sample->priv->duration = jammo_meam_get_cached_duration(sample->priv->real_filename)) != JAMMO_DURATION_INVALID) {
 				g_object_set(sample->priv->element,
